import { useState, useRef } from 'react';

import drums from '../assets/music/drums.mp3';
import flute from '../assets/music/flute.mp3';
import guitar from '../assets/music/guitar.mp3';
import mouthOrgan from '../assets/music/mouth-organ.mp3';
import piano from '../assets/music/piano.mp3';
import sitar from '../assets/music/sitar.mp3';
import tabla from '../assets/music/tabla.mp3';
import violin from '../assets/music/violin.mp3';
import { AudioLines, CirclePlay, Pause, Play } from 'lucide-react';

export default function Music() {
  const [currentTrack, setCurrentTrack] = useState(null);
  const [isPlaying, setIsPlaying] = useState(false);
  const audioRef = useRef(null);

  const files = [
    {
      id: 1,
      title: 'Majestic Drums',
      by: 'John Doe',
      source: drums,
      color: 'bg-orange-100',
    },
    {
      id: 2,
      title: 'Soothing Flute',
      by: 'Sarah Doe',
      source: flute,
      color: 'bg-blue-100',
    },
    {
      id: 3,
      title: 'Melodious Guitar',
      by: 'Alex Kuzmin',
      source: guitar,
      color: 'bg-green-100',
    },
    {
      id: 4,
      title: 'Melodious Mouth Organ',
      by: 'Felix Doe',
      source: mouthOrgan,
      color: 'bg-yellow-100',
    },
    {
      id: 5,
      title: 'Natural Piano',
      by: 'Kate Doe',
      source: piano,
      color: 'bg-purple-100',
    },
    {
      id: 6,
      title: 'Classical Sitar',
      by: 'Kamil Aszkowski',
      source: sitar,
      color: 'bg-red-100',
    },
    {
      id: 7,
      title: 'Traditional Tabla',
      by: 'Matthew James',
      source: tabla,
      color: 'bg-indigo-100',
    },
    {
      id: 8,
      title: 'Majestic Violin',
      by: 'William James',
      source: violin,
      color: 'bg-pink-100',
    },
  ];

  const handlePlayPause = (track) => {
    if (currentTrack && currentTrack.id === track.id) {
      if (isPlaying) {
        audioRef.current.pause();
      } else {
        audioRef.current
          .play()
          .catch((e) => console.log('Audio playback failed:', e));
      }
      setIsPlaying(!isPlaying);
    } else {
      setCurrentTrack(track);
      setIsPlaying(true);

      if (audioRef.current) {
        audioRef.current.load();
        audioRef.current
          .play()
          .catch((e) => console.log('Audio playback failed:', e));
      }
    }
  };

  return (
    <div className='flex flex-col items-center justify-center bg-gray-100 p-6 md:p-10 min-h-screen'>
      <h2 className='text-center text-2xl lg:text-3xl font-bold text-gray-900'>
        Music Collection Page
      </h2>
      <p className='mt-2 text-center text-gray-600'>
        Enjoy these musical pieces created by our talented members.
      </p>

      {currentTrack && (
        <div className='w-full max-w-md mt-8 p-4 bg-white rounded-lg shadow-md'>
          <div className='flex items-center justify-between'>
            <div>
              <h3 className='font-medium text-gray-900'>
                {currentTrack.title}
              </h3>
              <p className='text-sm text-gray-500'>By {currentTrack.by}</p>
            </div>
            <button
              onClick={() => handlePlayPause(currentTrack)}
              className='p-2 rounded-full bg-violet-100 hover:bg-violet-200 text-violet-800'
            >
              {isPlaying ? (
                <Pause className='text-violet-800 h-5 w-5' />
              ) : (
                <Play className='text-violet-800 h-5 w-5' />
              )}
            </button>
          </div>

          <audio
            ref={audioRef}
            className='w-full mt-4'
            controls
            src={currentTrack.source}
            onEnded={() => setIsPlaying(false)}
          />
        </div>
      )}

      <ul
        role='list'
        className='mt-8 grid grid-cols-1 gap-8 sm:grid-cols-2 md:grid-cols-3 lg:grid-cols-4 w-full '
      >
        {files.map((file) => (
          <li key={file.id} className='relative'>
            <div
              className={`${file.color} p-4 rounded-lg shadow-sm hover:shadow-md transition-shadow duration-200 cursor-pointer`}
              onClick={() => handlePlayPause(file)}
            >
              <div className='aspect-w-1 aspect-h-1 flex items-center justify-center h-32'>
                {currentTrack && currentTrack.id === file.id ? (
                  isPlaying ? (
                    <AudioLines className='text-violet-600 h-10 w-10 animate-pulse' />
                  ) : (
                    <Play className='text-violet-600 h-10 w-10' />
                  )
                ) : (
                  <CirclePlay className='text-gray-600 h-10 w-10' />
                )}
              </div>
            </div>
            <p className='mt-2 block truncate text-sm font-medium text-gray-900'>
              {file.title}
            </p>
            <p className='block text-sm font-medium text-gray-500'>
              By {file.by}
            </p>
          </li>
        ))}
      </ul>

      {currentTrack && (
        <audio
          ref={audioRef}
          className='hidden'
          onEnded={() => setIsPlaying(false)}
        >
          <source src={currentTrack.source} type='audio/mpeg' />
          Your browser does not support the audio element.
        </audio>
      )}
    </div>
  );
}
