import Link from 'next/link';
import { Button } from '@/components/ui/button';
import {
  Card,
  CardContent,
  CardDescription,
  CardHeader,
  CardTitle,
} from '@/components/ui/card';
import { MessageCircle, Share2, Users, HelpCircle } from 'lucide-react';

export default function LandingPage() {
  return (
    <div className='flex flex-col'>
      <main className='flex-1'>
        {/* Hero section */}
        <section className='w-full py-12 md:py-24 lg:py-32 xl:py-48'>
          <div className='container px-4 md:px-6 mx-auto'>
            <div className='flex flex-col items-center space-y-4 text-center'>
              <div className='space-y-2'>
                <h1 className='text-3xl font-bold tracking-tighter sm:text-4xl md:text-5xl lg:text-6xl'>
                  Welcome to Uniconnect
                </h1>
                <p className='mx-auto max-w-[700px] text-gray-500 md:text-xl dark:text-gray-400'>
                  Connect, share, and thrive with your fellow RHUL students
                </p>
              </div>
              <div className='space-x-4'>
                <Button asChild>
                  <Link href='/app'>Get Started</Link>
                </Button>
                <Button variant='outline'>Learn More</Button>
              </div>
            </div>
          </div>
        </section>
        {/* Feaures section */}
        <section className='w-full py-12 md:py-24 lg:py-32 bg-gray-100 dark:bg-gray-800'>
          <div className='container px-4 md:px-6 mx-auto'>
            <h2 className='text-3xl font-bold tracking-tighter sm:text-4xl md:text-5xl text-center mb-8'>
              Features
            </h2>
            <div className='grid gap-6 sm:grid-cols-2 lg:grid-cols-4'>
              <Card>
                <CardHeader>
                  <MessageCircle className='h-6 w-6 mb-2' />
                  <CardTitle>Group Discussions</CardTitle>
                </CardHeader>
                <CardContent>
                  <p>Engage in topic-based group chats with your peers.</p>
                </CardContent>
              </Card>
              <Card>
                <CardHeader>
                  <Share2 className='h-6 w-6 mb-2' />
                  <CardTitle>Resource Sharing</CardTitle>
                </CardHeader>
                <CardContent>
                  <p>Share and access books, notes, and study materials.</p>
                </CardContent>
              </Card>
              <Card>
                <CardHeader>
                  <Users className='h-6 w-6 mb-2' />
                  <CardTitle>Idea Exchange</CardTitle>
                </CardHeader>
                <CardContent>
                  <p>
                    Share your innovative ideas and collaborate with others.
                  </p>
                </CardContent>
              </Card>
              <Card>
                <CardHeader>
                  <HelpCircle className='h-6 w-6 mb-2' />
                  <CardTitle>AI Chatbot</CardTitle>
                </CardHeader>
                <CardContent>
                  <p>
                    Get instant help and answers with our integrated chatbot.
                  </p>
                </CardContent>
              </Card>
            </div>
          </div>
        </section>
        {/* Testimonials section */}
        <section className='w-full py-12 md:py-24 lg:py-32'>
          <div className='container px-4 md:px-6 mx-auto'>
            <h2 className='text-3xl font-bold tracking-tighter sm:text-4xl md:text-5xl text-center mb-8'>
              What Students Say
            </h2>
            <div className='grid gap-6 sm:grid-cols-2 lg:grid-cols-3'>
              <Card>
                <CardHeader>
                  <CardTitle>Sarah J.</CardTitle>
                  <CardDescription>Computer Science, Year 2</CardDescription>
                </CardHeader>
                <CardContent>
                  &quot;Uniconnect has made it so much easier to collaborate on
                  projects and share resources. It&apos;s a game-changer!&quot;
                </CardContent>
              </Card>
              <Card>
                <CardHeader>
                  <CardTitle>Michael T.</CardTitle>
                  <CardDescription>English Literature, Year 3</CardDescription>
                </CardHeader>
                <CardContent>
                  &quot;The group discussions feature has been invaluable for
                  brainstorming ideas and getting feedback on my essays.&quot;
                </CardContent>
              </Card>
              <Card>
                <CardHeader>
                  <CardTitle>Aisha K.</CardTitle>
                  <CardDescription>Psychology, Year 1</CardDescription>
                </CardHeader>
                <CardContent>
                  &quot;As a student with dyslexia, I appreciate how accessible
                  and easy to navigate Uniconnect is. It&apos;s truly
                  inclusive!&quot;
                </CardContent>
              </Card>
            </div>
          </div>
        </section>
        {/* Join section */}
        <section className='w-full py-12 md:py-24 lg:py-32 bg-gray-100 dark:bg-gray-800'>
          <div className='container px-4 md:px-6 mx-auto'>
            <div className='flex flex-col items-center space-y-4 text-center'>
              <div className='space-y-2'>
                <h2 className='text-3xl font-bold tracking-tighter sm:text-4xl md:text-5xl'>
                  Join Uniconnect Today
                </h2>
                <p className='mx-auto max-w-[700px] text-gray-500 md:text-xl dark:text-gray-400'>
                  Start connecting with your RHUL community and make the most of
                  your university experience.
                </p>
              </div>
              <div className='w-full max-w-sm space-y-2'>
                <Button className='w-full'>Sign Up Now</Button>
              </div>
            </div>
          </div>
        </section>
      </main>
      <footer className='flex flex-col gap-2 sm:flex-row py-6 w-full shrink-0 items-center px-4 md:px-6 border-t'>
        <p className='text-xs text-gray-500 dark:text-gray-400'>
          © 2024 Uniconnect. All rights reserved.
        </p>
        <nav className='sm:ml-auto flex gap-4 sm:gap-6'>
          <Link className='text-xs hover:underline underline-offset-4' href='#'>
            Terms of Service
          </Link>
          <Link className='text-xs hover:underline underline-offset-4' href='#'>
            Privacy
          </Link>
          <Link className='text-xs hover:underline underline-offset-4' href='#'>
            Accessibility
          </Link>
        </nav>
      </footer>
    </div>
  );
}
